==> hadoop-2.10.2-src.tar.gz: hadoop-2.10.2-src/hadoop-tools/hadoop-openstack/src/main/java/org/apache/hadoop/fs/swift/http/HttpBodyContent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.fs.swift.http;

/**
 * Response tuple from GET operations; combines the input stream with the content length
 */
public class HttpBodyContent {
  private final long contentLength;
  private final HttpInputStreamWithRelease inputStream;

  /**
   * build a body response
   * @param inputStream input stream from the operatin
   * @param contentLength length of content; may be -1 for "don't know"
   */
  public HttpBodyContent(HttpInputStreamWithRelease inputStream,
                         long contentLength) {
    this.contentLength = contentLength;
    this.inputStream = inputStream;
  }

  public long getContentLength() {
    return contentLength;
  }

  public HttpInputStreamWithRelease getInputStream() {
    return inputStream;
  }
}

==> hadoop-3.2.4-src.tar.gz: hadoop-3.2.4-src/hadoop-tools/hadoop-openstack/src/main/java/org/apache/hadoop/fs/swift/http/HttpBodyContent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.fs.swift.http;

/**
 * Response tuple from GET operations; combines the input stream with the content length
 */
public class HttpBodyContent {
  private final long contentLength;
  private final HttpInputStreamWithRelease inputStream;

  /**
   * build a body response
   * @param inputStream input stream from the operation
   * @param contentLength length of content; may be -1 for "don't know"
   */
  public HttpBodyContent(HttpInputStreamWithRelease inputStream,
                         long contentLength) {
    this.contentLength = contentLength;
    this.inputStream = inputStream;
  }

  public long getContentLength() {
    return contentLength;
  }

  public HttpInputStreamWithRelease getInputStream() {
    return inputStream;
  }
}
